==> fred-ferda-3.22.1.tar.gz: fred-ferda-3.22.1/ferda/plugins.py <==
"""Ferda plugins configuration."""
import warnings
from collections import OrderedDict
from typing import Callable, List, Optional, Tuple

from pydantic import BaseModel

from ferda.models import User
from ferda.utils import AnyStr

warnings.warn(
    "Module `ferda.plugins` is deprecated and will be removed in Ferda 4.0. Menu items should be handled by frontend. "
    "You can use `create_permissions` plugin hook to create permissions on application startup.",
    DeprecationWarning,
)


class PluginConfig(BaseModel):
    """Ferda plugin configuration.

    Attributes:
        name: Name of the plugin. This name is shown in plugins main menu.
        url: Root url of the plugin.
            This url is used as target in plugins main menu.
            Usually, this value is computed by reverse_lazy method.
        icon: Name of icon from Material Design icon list.
        access: Function that takes user as its first argument and
            returns whether that user can access the plugin.
        permissions: List of tuples (name, description) of permissions.
            Permission names should contain exactly one dot separating
            content type from permission codename, e.g. `ferda_registry.can_view`.
    """

    name: AnyStr
    url: AnyStr
    icon: Optional[str] = None
    access: Callable[[User], bool] = lambda x: True
    permissions: List[Tuple[str, str]] = []

    class Config:
        arbitrary_types_allowed = True


def register(app_name: str, config: PluginConfig) -> None:
    """Register ferda plugin."""
    CONFIG[app_name] = config


CONFIG = OrderedDict()  # type: OrderedDict[str, PluginConfig]

==> fred-ferda-3.23.0rc2.tar.gz: fred-ferda-3.23.0rc2/ferda/plugins.py <==
"""Ferda plugins configuration."""
import warnings
from collections import OrderedDict
from typing import Callable, List, Optional, Tuple

from pydantic import BaseModel

from ferda.models import User
from ferda.utils import AnyStr

warnings.warn(
    "Module `ferda.plugins` is deprecated and will be removed in Ferda 4.0. Menu items should be handled by frontend. "
    "You can use `create_permissions` plugin hook to create permissions on application startup.",
    DeprecationWarning,
)


class PluginConfig(BaseModel):
    """Ferda plugin configuration.

    Attributes:
        name: Name of the plugin. This name is shown in plugins main menu.
        url: Root url of the plugin.
            This url is used as target in plugins main menu.
            Usually, this value is computed by reverse_lazy method.
        icon: Name of icon from Material Design icon list.
        access: Function that takes user as its first argument and
            returns whether that user can access the plugin.
        permissions: List of tuples (name, description) of permissions.
            Permission names should contain exactly one dot separating
            content type from permission codename, e.g. `ferda_registry.can_view`.
    """

    name: AnyStr
    url: AnyStr
    icon: Optional[str] = None
    access: Callable[[User], bool] = lambda x: True  # noqa: E731
    permissions: List[Tuple[str, str]] = []

    class Config:
        arbitrary_types_allowed = True


def register(app_name: str, config: PluginConfig) -> None:
    """Register ferda plugin."""
    CONFIG[app_name] = config


CONFIG = OrderedDict()  # type: OrderedDict[str, PluginConfig]
